@@ -1,11 +1,12 @@
 /*
- *  $Id: MSR-K6.c,v 1.7 2001/12/10 20:17:34 davej Exp $
+ *  $Id: MSR-K6.c,v 1.10 2002/11/25 15:34:30 davej Exp $
  *  This file is part of x86info.
  *  (C) 2001 Dave Jones.
  *
  *  Licensed under the terms of the GNU GPL License version 2.
  *
  *  AMD-K6 specific MSR information
+ *  See 21329h1.pdf for more details.
  *
  */
 
@@ -22,7 +23,6 @@ void dump_k6_MSR (struct cpudata *cpu)
 	if (!user_is_root)
 		return;
 
-	printf("\t\t\t\t31       23       15       7 \n");
 	dumpmsr(cpu->number, 0xC0000082, 32);
 
 	/* Original K6 or K6-2 (old core). */
@@ -49,5 +49,30 @@ void dump_k6_MSR (struct cpudata *cpu)
 		}
 	}
 
+	/* Dump EWBE register on K6-2 & K6-3 */
+	if ((cpu->family==5) && (cpu->model>=8)) {
+		if (read_msr (cpu->number, 0xC0000080, &val) == 1) {
+			if (val & (1<<0))
+				printf ("System call extension present.\n");
+			if (val & (1<<1))
+				printf ("Data prefetch enabled.\n");
+			else
+				printf ("Data prefetch disabled.\n");
+			printf ("EWBE mode: ");
+			switch ((val & (1<<2|1<<3|1<<4))>>2) {
+				case 0:	printf ("strong ordering (slowest performance)\n");
+					break;
+				case 1:	printf ("speculative disable (close to best performance)\n");
+					break;
+				case 2:	printf ("invalid\n");
+					break;
+				case 3:	printf ("global disable (best performance)\n");
+					break;
+			}
+		} else {
+			printf ("Couldn't read EFER register.\n");
+		}
+	}
+
 	printf ("\n");
 }
