@@ -46,6 +46,9 @@ void Identify_Intel (struct cpudata *cpu)
 	cpu->brand = (ebx & 0xf);
 	reserved = eax >> 14;
 
+	cpu->flags_ecx = ecx; // Used for identification of Core 2
+	cpu->flags_edx = edx;
+
 	decode_Intel_caches(cpu, 0);
 
 	switch (cpu->family) {
@@ -599,15 +602,138 @@ void Identify_Intel (struct cpudata *cpu)
 		break;
 
 	case 0x6e0:
-		add_to_cpuname("Core Solo/Duo ");
+		add_to_cpuname("Core ");
+		switch (cpu->stepping) {
+			case 8:
+				switch (cpu->MHz) {
+				case 1000:
+					// SL99W/SL8W7 533FSB
+					add_to_cpuname("Duo U2400/Solo U1300 [C-0]");
+					break;
+				case 1200:
+					// SL8W6 533FSB
+					add_to_cpuname("Solo U1400 [C-0]");
+					break;
+				case 1500:
+					// SL8VX 667FSB
+					add_to_cpuname("Duo L2300 [C-0]");
+					break;
+				case 1600:
+					// SL9JE/SL9JV/SL8VR/SL8VV/SL8VY/SL8W3/SL8VW 667FSB
+					add_to_cpuname("Solo T1300/Duo T2300(E)/Duo L2400");
+					break;
+				case 1800:
+					// SL92X/SL8VQ/SL8VU/SL92V/SL92X 667FSB
+					add_to_cpuname("Solo T1400/Duo T2400 [C-0]");
+					break;
+				case 2000:
+					// SL8VP/SL8VT/SL92U/SL92W 667FSB
+					add_to_cpuname("Solo T1500/Duo T2500 [C-0]");
+					break;
+				case 2150:
+					// SL8VN/SL8VS 667FSB
+					add_to_cpuname("Duo T2600 [C-0]");
+					break;
+				}
+				break;
+			case 0xc:
+				switch (cpu->MHz) {
+				case 1200:
+					// SL99V 533FSB
+					add_to_cpuname("Duo U2500 [D-0]");
+					break;
+				case 1800:
+					// SL9JU 667FSB
+					add_to_cpuname("Duo L2500 [D-0]");
+					break;
+				case 2300:
+					// SL9JP/SL9K4 667FSB
+					add_to_cpuname("Duo T2700 [D-0]");
+					break;
+				}
+		}
+		break;
+
+	case 0x6f0:
+		add_to_cpuname("Core 2 ");
+		// Do a numerical hack, because they aren't exactly 2100Mhz etc.
+		// FIXME: Come up with a better way to do this, easiest if
+		// Intel gives us an Extreme chip to compare against others ;-)
+		if(cpu->MHz/100 >= 29) {
+			add_to_cpuname("Extreme ");
+		} else {
+			add_to_cpuname("Duo ");
+		}
+		// Check for Thermal Monitor 2 feature bit, because only the
+		// non-mobile processors have it
+		// TODO: Clean up Feature bit handling
+		if(cpu->flags_ecx & (1 << 8)) {
+			cpu->connector = CONN_LGA775;
+			switch (cpu->MHz) {
+			case 1800:
+				// SL9SA 1066FSB 2MB L2
+				add_to_cpuname("E6300");
+				break;
+			case 2150:
+				// SL9S9 1066FSB 2MB L2
+				add_to_cpuname("E6400");
+				break;
+			case 2400:
+				// SL9S8 1066FSB 4MB L2
+				add_to_cpuname("E6600");
+				break;
+			case 2600:
+				// SL9S7 1066FSB 4MB L2
+				add_to_cpuname("E6700");
+				break;
+			case 2950:
+				// SL9S5 1066FSB 4MB L2
+				add_to_cpuname("E6800/X6800");
+				break;
+			}
+		} else {
+			cpu->connector = CONN_MICROFCBGA;
+			add_to_cpuname("Mobile ");
+			switch (cpu->MHz) {
+			case 1600:
+				// SL9SH/SL9SQ 1.6GHz 667FSB
+				add_to_cpuname("T5500");
+				break;
+			case 1800:
+				// SL9SG/SL9SP 1.8GHz 667FSB
+				add_to_cpuname("T5600");
+			case 2000:
+				// SL9SF/SL9SL 667FSB
+				add_to_cpuname("T7200");
+				break;
+			case 2100:
+				// SL9SE/SL9SK 667FSB
+				add_to_cpuname("T7400");
+				break;
+			case 2300:
+				// SL9SD/SL9SJ 667FSB
+				add_to_cpuname("T7600");
+				break;
+			}
+		}
+		// TODO: Check that the Mobile chips really are stepping 6 as well.
+		// The Sept 06 Core 2 Intel Errata documentation says there are
+		// at least B1 and B2 steppings.
+		switch(cpu->stepping) {
+		// TODO: B1 as stepping 5 is a 100% guess
+		case 5:
+			add_to_cpuname(" [B1]");
+			break;
+		case 6:
+			add_to_cpuname(" [B2]");
+			break;
+		}
 		break;
 
 	case 0x700:		/* Family 7 */
 		add_to_cpuname("Itanium");
 		break;
 
-//FIXME: What is SL4X5 ? 
-
 	case 0xF00:	/* Family 15 */
 		cpu->connector = CONN_SOCKET_423;
 		cpu->datasheet_url = strdup(p4_423_datasheet);
@@ -641,7 +767,7 @@ void Identify_Intel (struct cpudata *cpu)
 		case 1:
 			//400FSB 256K L2
 			//SSpec MHz L3
-			//SL5G8 1.6 1M 
+			//SL5G8 1.6 1M
 			//SL5S4 1.6 1M
 			//SL5FZ 1.4 512K
 			//SL5RZ 1.4 512K
